@@ -8,7 +8,7 @@
 int encfs_stash_get_info (const char *crypt_dir, char **output);
 int encfs_stash_change_password (const char *crypt_dir, const char *old_password, const char *new_password, char **output);
 int encfs_stash_new (const char *crypt_dir, const char *mount_dir, const char *password);
-int encfs_stash_mount(const char *crypt_dir, const char *mount_dir, const char *password, int idle_timeout, char **output);
+int encfs_stash_mount(const char *crypt_dir, const char *mount_dir, const char *password, int idle_timeout, bool allow_other, char **output);
 int encfs_stash_unmount (const char *mount_dir);
 bool is_mounted(const char *mount_dir);
 
